@@ -6,7 +6,7 @@
 # @Software: PyCharm
 
 """生意参谋解密调用此文件，不要调用SYCMCryptUtil"""
-from util.xzg_util.XZGUtil.SYCMCryptUtil import decrypt, transitId
+from XZGUtil.SYCMCryptUtil import decrypt, transitId
 
 def get_transitId():
     return transitId()
